@@ -1,11 +1,9 @@
-import re
-import webbot
-import time
-from bs4 import BeautifulSoup
-import numpy as np
-import pandas as pd
-import requests
-import json
+from re import search
+from numpy import array as np_array
+from numpy import unique as np_unique
+from pandas import DataFrame as pd_DataFrame
+from requests import get as requests_get
+from json import loads as json_loads
 import asyncio
 from pyppeteer import launch
 
@@ -23,7 +21,7 @@ class AbstractScraper:
         self.second = "&highlight=true&returnFacets=ALL&returnType=SEARCH&matchPubs=true&rowsPerPage=100&pageNumber=1"
 
     async def _open(self, url=None, keywords=None, operator="OR", in_data="author",
-              pages=2):
+                    pages=2):
         """
         defines the users search query
 
@@ -36,40 +34,41 @@ class AbstractScraper:
         :param pages: number of pages that is iterated over
         :type pages: int
         :param in_data: "author" or "all_meta" whether to search in author
-                        keywords or all metadata
+                         keywords or all metadata
         :type in_data: string
         :return:
         """
         await self._open_pypeteer(url, keywords, operator, in_data, pages)
 
     async def _open_pypeteer(self, url=None, keywords=None, operator="OR", in_data="author",
-    pages=2):
+                             pages=2):
         self._create_url(url, keywords, operator, in_data)
         self.html_page = []
         print("The algorithm is iterating through", pages,
               "pages")
         browser = await launch()
         page = await browser.newPage()
-        await page.goto(self.url, {'waitUntil' : 'networkidle0'})
+        await page.goto(self.url, {'waitUntil': 'networkidle0'})
 
         self.linkstorage = []
 
         elements = await page.querySelectorAll('a')
         for element in elements:
             self.linkstorage.append(await page.evaluate('(element) => element.href', element))
-        for i in range(2, pages+1):
+        for i in range(2, pages + 1):
             self._create_new_url(i)
-            await page.goto(self.url, {'waitUntil' : 'networkidle0'})
+            await page.goto(self.url, {'waitUntil': 'networkidle0'})
             elements = await page.querySelectorAll('a')
             for element in elements:
                 self.linkstorage.append(await page.evaluate('(element) => element.href', element))
         await browser.close()
 
     def _add_page_number(self, page, position):
-        self.url = self.url[:position+len("pageNumber=")] + str(page) + self.url[position+len("pageNumber=")+len(str(page-1)):]
+        self.url = self.url[:position + len("pageNumber=")] + str(
+            page) + self.url[position + len("pageNumber=") + len(str(page - 1)):]
 
     def _add_str_plus_page_number(self, page):
-        if self.url[-1] =='?':
+        if self.url[-1] == '?':
             self.url = self.url + "pageNumber=" + str(page)
         else:
             self.url = self.url + "?pageNumber" + str(page)
@@ -131,9 +130,9 @@ class AbstractScraper:
             if (document in link) & (citation not in link):
                 self.data.append(link)
         # remove unnecessary results of the href search
-        self.data = np.array(self.data)
+        self.data = np_array(self.data)
         # remove duplicates that are in there due to multiple occurrence in the
-        self.data = np.unique(self.data)
+        self.data = np_unique(self.data)
         print("Total number of abstracts that will be scraped:",
               len(self.data))
 
@@ -148,10 +147,10 @@ class AbstractScraper:
         for i in range(len(self.data)):
             # only "try" because sometimes the javascript is corrupted
             try:
-                data = json.loads(
-                    re.search(
+                data = json_loads(
+                    search(
                         r"\.metadata=(.*?);",
-                        requests.get(self.data[i]).text,
+                        requests_get(self.data[i]).text,
                     ).group(1)
                 )
                 # only get title and abstracts -> we could also go for
@@ -161,10 +160,16 @@ class AbstractScraper:
 
                 self.title.append(title)
                 self.abstracts.append(data)
-            except:
+            except BaseException:
                 pass
 
-    def get(self, url=None, keywords=None, operator="OR", pages=2, in_data="author"):
+    def get(
+            self,
+            url=None,
+            keywords=None,
+            operator="OR",
+            pages=2,
+            in_data="author"):
         self._open(
             url=url, keywords=keywords, operator=operator, pages=pages,
             in_data=in_data
@@ -194,20 +199,18 @@ class AbstractScraper:
         self._find_links()
         self._find_abstracts()
 
-        data = pd.DataFrame({"text": self.abstracts, "titles": self.title})
+        data = pd_DataFrame({"text": self.abstracts, "titles": self.title})
         data = data.drop_duplicates()
         return data
 
 
+if __name__ == "__main__":
+    async def main():
+        AS = AbstractScraper()
+        data = await AS.get_abstracts(url=None, keywords=["dentistry", "teeth", "tooth"],
+                                      in_data="all_meta",
+                                      pages=3,
+                                      operator="or")
+        print(data)
 
-
-async def main():
-    AS = AbstractScraper()
-    data = await AS.get_abstracts(url=None, keywords=["dentistry", "teeth", "tooth"],
-            in_data="all_meta",
-            pages=3,
-            operator="or")
-    print(data)
-
-
-asyncio.get_event_loop().run_until_complete(main())
+    asyncio.get_event_loop().run_until_complete(main())
